@@ -1,12 +1,14 @@
 import os
+import socket
+import platform
 import tempfile
 from uuid import uuid1
 
-from ..pyxnat import Interface
+from .. import Interface
 
 _modulepath = os.path.dirname(os.path.abspath(__file__))
 
-central = Interface('http://central.xnat.org', 'nosetests', 'nosetests')
+central = Interface('https://central.xnat.org', 'nosetests', 'nosetests')
 
 _id_set1 = {
     'sid':uuid1().hex,
@@ -55,6 +57,10 @@ def test_reconstruction_create():
     reco_1.create()
     assert reco_1.exists()
 
+def test_provenance():
+    reco_1.provenance.set({'program':'nosetests'})
+    assert reco_1.provenance.get()[0]['program'] == 'nosetests'
+
 def test_multi_create():
     asse_2 = central.select('/projects/nosetests/subjects/%(sid)s'
                             '/experiments/%(eid)s'
@@ -136,19 +142,47 @@ def test_put_file():
                                                 os.stat(local_path).st_size
 
 def test_get_file():
-    fpath = subj_1.resource('test').file('hello.txt').get()
+    fh = subj_1.resource('test').file('hello.txt')
+
+    central.cache.set_usage(expiration=0)
+
+    fpath = fh.get()
     assert os.path.exists(fpath)
     assert open(fpath, 'rb').read() == 'Hello XNAT!\n'
 
     custom = os.path.join(tempfile.gettempdir(), uuid1().hex)
     
-    subj_1.resource('test').file('hello.txt').get(custom)
-
+    fh.get(custom)
     assert os.path.exists(custom)
     assert not os.path.exists(fpath)
-    subj_1.resource('test').file('hello.txt').get()
-    assert not os.path.exists(custom)
-    os.remove(fpath)
+    fh.get()
+    assert os.path.exists(custom)
+    os.remove(custom)
+
+def test_put_dir_file():
+    local_path = os.path.join(_modulepath, 'hello_again.txt')
+    subj_1.resource('test').file('dir/hello.txt').put(local_path)
+    assert subj_1.resource('test').file('dir/hello.txt').exists()
+    assert long(subj_1.resource('test').file('dir/hello.txt').size()) == \
+                                                os.stat(local_path).st_size
+
+def test_get_dir_file():
+    fh = subj_1.resource('test').file('dir/hello.txt')
+
+    central.cache.set_usage(expiration=0)
+
+    fpath = fh.get()
+    assert os.path.exists(fpath)
+    assert open(fpath, 'rb').read() == 'Hello again!\n'
+
+    custom = os.path.join(tempfile.gettempdir(), uuid1().hex)
+    
+    fh.get(custom)
+    assert os.path.exists(custom)
+    assert not os.path.exists(fpath)
+    fh.get()
+    assert os.path.exists(custom)
+    os.remove(custom)
 
 def test_get_copy_file():
     fpath = os.path.join(tempfile.gettempdir(), uuid1().hex)
@@ -159,6 +193,13 @@ def test_get_copy_file():
     fd.close()
     os.remove(fpath)
 
+    central.cache.set_usage(expiration=1)
+
+def test_file_last_modified():
+    f = subj_1.resource('test').file('hello.txt')
+    assert isinstance(f.last_modified(), basestring)
+    assert len(f.last_modified()) > 0
+
 def test_last_modified():
     sid = subj_1.id()
 
@@ -190,3 +231,4 @@ def test_project_configuration():
     assert project.user_role('nosetests') == 'owner'
     
 
+    
